-module(element_password).
%%-author('Vladimir Galunshchikov').

-include_lib("nitro/include/nitro.hrl").
-include_lib("nitro/include/event.hrl").

-export([
  render_element/1
]).


render_element(Record) when Record#password.show_if == false -> [<<>>];

render_element(Record) ->
  Id = case Record#password.postback of
    [] -> Record#password.id;
    Postback ->
      ID0 = case Record#password.id of
        [] -> nitro:temp_id();
        I -> I
      end,
      nitro:wire( #event{type = click, postback = Postback, target = ID0,
                         source = Record#password.source,
                         delegate = Record#password.delegate} ),
      ID0
  end,
  List = [
    %% global
    {<<"accesskey">>, Record#password.accesskey},
    {<<"class">>, Record#password.class},
    {<<"contenteditable">>,
       case Record#password.contenteditable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"contextmenu">>, Record#password.contextmenu},
    {<<"dir">>,
       case Record#password.dir of
         "ltr" -> "ltr";
         "rtl" -> "rtl";
         "auto" -> "auto";
         _ -> []
       end},
    
    {<<"draggable">>,
       case Record#password.draggable of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"dropzone">>, Record#password.dropzone},
    {<<"hidden">>,
       case Record#password.hidden of
         "hidden" -> "hidden";
         _ -> []
       end},
    
    {<<"id">>, Id},
    {<<"lang">>, Record#password.lang},
    {<<"spellcheck">>,
       case Record#password.spellcheck of
         true -> "true";
         false -> "false";
         _ -> []
       end},
    
    {<<"style">>, Record#password.style},
    {<<"tabindex">>, Record#password.tabindex},
    {<<"title">>, Record#password.title},
    {<<"translate">>,
       case Record#password.contenteditable of
         "yes" -> "yes";
         "no" -> "no";
         _ -> []
       end},
    
    %% spec
    {<<"autocomplete">>,
       case Record#password.autocomplete of
         true -> "on";
         false -> "off";
         _ -> []
       end},
    
    {<<"autofocus">>,
       case Record#password.autofocus of
         true -> "autofocus";
         _ -> []
       end},
    
    {<<"disabled">>,
       case Record#password.disabled of
         true -> "disabled";
         _ -> []
       end},
    
    {<<"form">>, Record#password.form},
    {<<"maxlength">>, Record#password.maxlength},
    {<<"name">>, Record#password.name},
    {<<"pattern">>, Record#password.pattern},
    {<<"placeholder">>, Record#password.placeholder},
    {<<"readonly">>,
       case Record#password.readonly of
         true -> "readonly";
         _ -> []
       end},
    
    {<<"required">>,
       case Record#password.required of
         true -> "required";
         _ -> []
       end},
    
    {<<"size">>, Record#password.size},
    {<<"type">>, <<"password">>},
    {<<"value">>, Record#password.value} | Record#password.data_fields
  ],
  
  wf_tags:emit_tag(<<"input">>, nitro:render(Record#password.body), List).

